package com.fs.his.service;

import com.fs.aiChat.domain.DoctorAiChatMsg;
import com.fs.aiChat.domain.DoctorAiChatSession;
import com.fs.aiChat.param.Message;
import com.fs.aiChat.vo.DoctorAiVO;

import java.util.List;

/**
 * 对话关系Service接口
 *
 * @author fs
 * @date 2024-12-30
 */
public interface IHisDoctorAiChatSessionService
{
    /**
     * 查询对话关系
     *
     * @param sessionId 对话关系主键
     * @return 对话关系
     */
    public DoctorAiChatSession selectDoctorAiChatSessionBySessionId(Long sessionId);

    /**
     * 查询对话关系列表
     *
     * @param doctorAiChatSession 对话关系
     * @return 对话关系集合
     */
    public List<DoctorAiChatMsg> selectDoctorAiChatSessionListByUser(DoctorAiVO doctorAiChatSession);

    /**
     * 新增对话关系
     *
     * @param doctorAiChatSession 对话关系
     * @return 结果
     */
    public int insertDoctorAiChatSession(DoctorAiChatSession doctorAiChatSession);

    /**
     * 修改对话关系
     *
     * @param doctorAiChatSession 对话关系
     * @return 结果
     */
    public int updateDoctorAiChatSession(DoctorAiChatSession doctorAiChatSession);

    /**
     * 批量删除对话关系
     *
     * @param sessionIds 需要删除的对话关系主键集合
     * @return 结果
     */
    public int deleteDoctorAiChatSessionBySessionIds(Long[] sessionIds);

    /**
     * 删除对话关系信息
     *
     * @param sessionId 对话关系主键
     * @return 结果
     */
    public int deleteDoctorAiChatSessionBySessionId(Long sessionId);

    String chatByUser(Message message);

    List<DoctorAiChatSession> selectDoctorAiChatSessionList(DoctorAiChatSession doctorAiChatSession);

    DoctorAiChatSession selectChatSessionCVOBySessionId(Long sessionId);
}
